import { Data, DataUnknown } from '../../app/scripts/middleware/data';
import { Calc } from '../../app/scripts/math';

/*eslint-disable no-unused-vars*/

const overrideData = {};

class D1_GEN_V1 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM']);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_V_NOM').valNum() / Math.sqrt(3)) * 1.5
		);
	}
}

class D1_GEN_V2 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_V_NOM').valNum() / Math.sqrt(3)) * 1.5
		);
	}
}

class D1_GEN_V3 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_V_NOM').valNum() / Math.sqrt(3)) * 1.5
		);
	}
}

class D1_GEN_U31 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM']);
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_GEN_V_NOM').valNum() * 1.5
		);
	}
}

class D1_GEN_U23 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_GEN_V_NOM').valNum() * 1.5
		);
	}
}

class D1_GEN_U12 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_GEN_V_NOM').valNum() * 1.5
		);
	}
}

class D1_GEN_I1 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM', 'D1_GEN_KW_NOM']);
	}

	maxNum() {
		return this.calc.ceilHundred(
		//Pnom * 10^3 (conversion en watt) * 150%
		(new Data('D1_GEN_KW_NOM').valNum() * Math.pow(10, 3) * 1.5) /
		//Vnom * sqrt(3) * 0.8 (dans le pire cas : cosphi (faible) = 0.8)
		(new Data('D1_GEN_V_NOM').valNum() * Math.sqrt(3) * 0.8)
		);
	}
}

class D1_GEN_I2 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM', 'D1_GEN_KW_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		//Pnom * 10^3 (conversion en watt) * 150%
		(new Data('D1_GEN_KW_NOM').valNum() * Math.pow(10, 3) * 1.5) /
		//Vnom * sqrt(3) * 0.8 (dans le pire cas : cosphi (faible) = 0.8)
		(new Data('D1_GEN_V_NOM').valNum() * Math.sqrt(3) * 0.8)
		);
	}
}

class D1_GEN_I3 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_V_NOM', 'D1_GEN_KW_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		//Pnom * 10^3 (conversion en watt) * 150%
		(new Data('D1_GEN_KW_NOM').valNum() * Math.pow(10, 3) * 1.5) /
		//Vnom * sqrt(3) * 0.8 (dans le pire cas : cosphi (faible) = 0.8)
		(new Data('D1_GEN_V_NOM').valNum() * Math.sqrt(3) * 0.8)
		);
	}
}

class D1_GEN_P1 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KW_NOM']);
	}

	minNum() {
		return this.calc.floorHundred(
		(new Data('D1_GEN_KW_NOM').valNum() / 3) * -0.2
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_KW_NOM').valNum() / 3) * 1.5
		);
	}
}

class D1_GEN_P2 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KW_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	minNum() {
		return this.calc.floorHundred(
		(new Data('D1_GEN_KW_NOM').valNum() / 3) * -0.2
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_KW_NOM').valNum() / 3) * 1.5
		);
	}
}

class D1_GEN_P3 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KW_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	minNum() {
		return this.calc.floorHundred(
		(new Data('D1_GEN_KW_NOM').valNum() / 3) * -0.2
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_KW_NOM').valNum() / 3) * 1.5
		);
	}
}

class D1_GEN_Q1 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KVAR_NOM']);
	}

	minNum() {
		return this.calc.floorHundred(
		(new Data('D1_GEN_KVAR_NOM').valNum() / 3) * -1.5
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_KVAR_NOM').valNum() / 3) * 1.5
		);
	}
}

class D1_GEN_Q2 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KVAR_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	minNum() {
		return this.calc.floorHundred(
		(new Data('D1_GEN_KVAR_NOM').valNum() / 3) * -1.5
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_KVAR_NOM').valNum() / 3) * 1.5
		);
	}
}

class D1_GEN_Q3 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KVAR_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	minNum() {
		return this.calc.floorHundred(
		(new Data('D1_GEN_KVAR_NOM').valNum() / 3) * -1.5
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_GEN_KVAR_NOM').valNum() / 3) * 1.5
		);
	}
}

class D1_GEN_COSPHI1 extends Data {
	constructor(tag) {
		super(tag);
	}
}

class D1_GEN_COSPHI2 extends Data {
	constructor(tag) {
		super(tag);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}
}

class D1_GEN_COSPHI3 extends Data {
	constructor(tag) {
		super(tag);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}
}

class D1_GEN_KW extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KW_NOM']);
	}

	minNum() {
		return this.calc.floorHundred(
		new Data('D1_GEN_KW_NOM').valNum() * -0.2
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_GEN_KW_NOM').valNum() * 1.5
		);
	}
}

class D1_GEN_KVAR extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_GEN_KVAR_NOM']);
	}

	minNum() {
		return this.calc.floorHundred(
		new Data('D1_GEN_KVAR_NOM').valNum() * -1.5
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_GEN_KVAR_NOM').valNum() * 1.5
		);
	}
}

class D1_BUS_V1 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_BUS_V_NOM']);
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_BUS_V_NOM').valNum() / Math.sqrt(3)) * 1.5
		);
	}
}

class D1_BUS_V2 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_BUS_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_BUS_V_NOM').valNum() / Math.sqrt(3)) * 1.5
		);
	}
}

class D1_BUS_V3 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_BUS_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		(new Data('D1_BUS_V_NOM').valNum() / Math.sqrt(3)) * 1.5
		);
	}
}

class D1_BUS_U31 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_BUS_V_NOM']);
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_BUS_V_NOM').valNum() * 1.5
		);
	}
}

class D1_BUS_U23 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_BUS_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 1) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_BUS_V_NOM').valNum() * 1.5
		);
	}
}

class D1_BUS_U12 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_BUS_V_NOM']);
	}

	isVisible() {
		let voltageSchema = new Data('D1_VOLTAGE_SCHEMA').valNum();
		if (voltageSchema > 0) {
			return true;
		}
		return false;
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_BUS_V_NOM').valNum() * 1.5
		);
	}
}

class D1_BUS_I1 extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_TOT_NOM_KW', 'D1_GEN_V_NOM']);
	}

	maxNum() {
		return this.calc.ceilHundred(
		//Pnom * 10^3 (conversion en watt) * 150%
		(new Data('D1_TOT_NOM_KW').valNum() * Math.pow(10, 3) * 1.5) /
		//Vnom * sqrt(3) * 0.8 (dans le pire cas : cosphi (faible) = 0.8)
		(new Data('D1_GEN_V_NOM').valNum() * Math.sqrt(3) * 0.8)
		);
	}
}

class D1_BUS_P extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_TOT_NOM_KW']);
	}

	minNum() {
		return this.calc.floorHundred(
		new Data('D1_TOT_NOM_KW').valNum() * -0.2
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_TOT_NOM_KW').valNum() * 1.5
		);
	}
}

class D1_BUS_Q extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_TOT_NOM_KVAR']);
	}

	minNum() {
		return this.calc.floorHundred(
		new Data('D1_TOT_NOM_KVAR').valNum() * -1.5
		);
	}

	maxNum() {
		return this.calc.ceilHundred(
		new Data('D1_TOT_NOM_KVAR').valNum() * 1.5
		);
	}
}

//CANOPEN DI

class D1_CANOPEN_DI1 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 0) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI2 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 1) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI3 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 2) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI4 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 3) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI5 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 4) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI6 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 5) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI7 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 6) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI8 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 7) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI9 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 8) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI10 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 9) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI11 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 10) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI12 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 11) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI13 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 12) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI14 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 13) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI15 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 14) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI16 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 15) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI17 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 16) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI18 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 17) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI19 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 18) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI20 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 19) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI21 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 20) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI22 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 21) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI23 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 22) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI24 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 23) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI25 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 24) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI26 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 25) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI27 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 26) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI28 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 27) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI29 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 28) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI30 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 29) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI31 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 30) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_DI32 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDIN() > 31) {
			return true;
		}
		return false;
	}
}

//CANOPEN DO

class D1_DO01 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 0) {
			return true;
		}
		return false;
	}
}

class D1_DO02 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 1) {
			return true;
		}
		return false;
	}
}

class D1_DO03 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 2) {
			return true;
		}
		return false;
	}
}

class D1_DO04 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 3) {
			return true;
		}
		return false;
	}
}

class D1_DO05 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 4) {
			return true;
		}
		return false;
	}
}

class D1_DO06 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 5) {
			return true;
		}
		return false;
	}
}

class D1_DO07 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 6) {
			return true;
		}
		return false;
	}
}

class D1_DO08 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 7) {
			return true;
		}
		return false;
	}
}

class D1_DO09 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 8) {
			return true;
		}
		return false;
	}
}

class D1_DO10 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 9) {
			return true;
		}
		return false;
	}
}

class D1_DO11 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 10) {
			return true;
		}
		return false;
	}
}

class D1_DO12 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 11) {
			return true;
		}
		return false;
	}
}

class D1_DO13 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 12) {
			return true;
		}
		return false;
	}
}

class D1_DO14 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 13) {
			return true;
		}
		return false;
	}
}

class D1_DO15 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 14) {
			return true;
		}
		return false;
	}
}

class D1_DO16 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 15) {
			return true;
		}
		return false;
	}
}

class D1_DO17 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 16) {
			return true;
		}
		return false;
	}
}

class D1_DO18 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 17) {
			return true;
		}
		return false;
	}
}

class D1_DO19 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 18) {
			return true;
		}
		return false;
	}
}

class D1_DO20 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 19) {
			return true;
		}
		return false;
	}
}

class D1_DO21 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 20) {
			return true;
		}
		return false;
	}
}

class D1_DO22 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 21) {
			return true;
		}
		return false;
	}
}

class D1_DO23 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 22) {
			return true;
		}
		return false;
	}
}

class D1_DO24 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 23) {
			return true;
		}
		return false;
	}
}

class D1_DO25 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 24) {
			return true;
		}
		return false;
	}
}

class D1_DO26 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 25) {
			return true;
		}
		return false;
	}
}

class D1_DO27 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 26) {
			return true;
		}
		return false;
	}
}

class D1_DO28 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 27) {
			return true;
		}
		return false;
	}
}

class D1_DO29 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 28) {
			return true;
		}
		return false;
	}
}

class D1_DO30 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 29) {
			return true;
		}
		return false;
	}
}

class D1_DO31 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 30) {
			return true;
		}
		return false;
	}
}

class D1_DO32 extends Data {
	constructor(tag) {
		super(tag);
	}
	isVisible() {
		let D1_CANOPEN_CONFIG_TYPE = new overrideData.D1_CANOPEN_CONFIG_TYPE('D1_CANOPEN_CONFIG_TYPE');
		if (D1_CANOPEN_CONFIG_TYPE.valNumDOUT() > 31) {
			return true;
		}
		return false;
	}
}

class D1_CANOPEN_CONFIG_TYPE extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies([
			'D1_MOD01_NB_DIGITAL_INPUT', 'D1_MOD02_NB_DIGITAL_INPUT', 'D1_MOD03_NB_DIGITAL_INPUT',
			'D1_MOD04_NB_DIGITAL_INPUT', 'D1_MOD01_NB_DIGITAL_OUTPUT', 'D1_MOD02_NB_DIGITAL_OUTPUT',
			'D1_MOD03_NB_DIGITAL_OUTPUT', 'D1_MOD04_NB_DIGITAL_OUTPUT']);
	}
	valNum() {
		if (this.valNumDIN() > this.valNumDOUT()) {
			return this.valNumDIN();
		}
		return this.valNumDOUT();
	}
	valNumDIN() {
		let D1_CANOPEN_DIN_1 = new Data('D1_MOD01_NB_DIGITAL_INPUT').valNum();
		let D1_CANOPEN_DIN_2 = new Data('D1_MOD02_NB_DIGITAL_INPUT').valNum();
		let D1_CANOPEN_DIN_3 = new Data('D1_MOD03_NB_DIGITAL_INPUT').valNum();
		let D1_CANOPEN_DIN_4 = new Data('D1_MOD04_NB_DIGITAL_INPUT').valNum();
		return D1_CANOPEN_DIN_1 + D1_CANOPEN_DIN_2 + D1_CANOPEN_DIN_3 +
		D1_CANOPEN_DIN_4;
	}
	valNumDOUT() {
		let D1_CANOPEN_DOUT_1 = new Data('D1_MOD01_NB_DIGITAL_OUTPUT').valNum();
		let D1_CANOPEN_DOUT_2 = new Data('D1_MOD02_NB_DIGITAL_OUTPUT').valNum();
		let D1_CANOPEN_DOUT_3 = new Data('D1_MOD03_NB_DIGITAL_OUTPUT').valNum();
		let D1_CANOPEN_DOUT_4 = new Data('D1_MOD04_NB_DIGITAL_OUTPUT').valNum();
		return D1_CANOPEN_DOUT_1 + D1_CANOPEN_DOUT_2 + D1_CANOPEN_DOUT_3 +
		D1_CANOPEN_DOUT_4;
	}
}

//Digital IO

class D1_INPUT1 extends Data {
	constructor(tag) {
		super(tag);
	}
}

//Engine

class D1_ENGINE_RPM extends Data {
	constructor(tag) {
		super(tag);
		this.calc = new Calc();
		this.setDependencies(['D1_ACTIVE_SPEED_SETPOINT']);
	}
	maxNum() {
		return this.calc.ceilHundred(
			new Data('D1_ACTIVE_SPEED_SETPOINT').valNum() * 1.5
		);
	}
}

class D1_OIL_PRESS extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_J1939_ENGINE_MODEL', 'D1_AN1_CALIB01', 'D1_AN1_CALIB02', 'D1_AN1_CALIB03', 'D1_AN1_CALIB04',
			'D1_AN1_CALIB05', 'D1_AN1_CALIB06', 'D1_AN1_CALIB07', 'D1_AN1_CALIB08', 'D1_AN1_CALIB09',
			'D1_AN1_CALIB10', 'D1_AN1_CALIB11']);
		this.tagsArray = ['D1_AN1_CALIB01', 'D1_AN1_CALIB02', 'D1_AN1_CALIB03', 'D1_AN1_CALIB04',
			'D1_AN1_CALIB05', 'D1_AN1_CALIB06', 'D1_AN1_CALIB07', 'D1_AN1_CALIB08', 'D1_AN1_CALIB09',
			'D1_AN1_CALIB10', 'D1_AN1_CALIB11'];
	}
	minNum() {
		let j1939 = new Data('D1_J1939_ENGINE_MODEL').valNum();
		if (!j1939) {
			let calibValArray = [];
			this.tagsArray.forEach((item) => {
				calibValArray.push(new Data(item).valNum());
			});
			return Math.min(...calibValArray);
		}
		return new Data('D1_OIL_PRESS').minNum();
	}
	maxNum() {
		const MAX_BAR = 10;
		let unit = new Data('D1_OIL_PRESS').unit();
		let j1939 = new Data('D1_J1939_ENGINE_MODEL').valNum();
		if (!j1939) {
			let calibValArray = [];
			this.tagsArray.forEach((item) => {
				calibValArray.push(new Data(item).valNum());
			});
			return Math.max(...calibValArray);
		} else if (unit === 'R2_KILOPASCAL') {
			return MAX_BAR * 100;
		} else if (unit === 'R2_PSI') {
			return MAX_BAR * 14.5038;
		} else if (unit === 'R2_MBAR') {
			return MAX_BAR * 1000;
		}
		return MAX_BAR;
	}
}

class D1_WATER_TEMP extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_AN2_CALIB01', 'D1_AN2_CALIB02', 'D1_AN2_CALIB03', 'D1_AN2_CALIB04',
			'D1_AN2_CALIB05', 'D1_AN2_CALIB06', 'D1_AN2_CALIB07', 'D1_AN2_CALIB08', 'D1_AN2_CALIB09',
			'D1_AN2_CALIB10', 'D1_AN2_CALIB11']);
		this.tagsArray = ['D1_AN2_CALIB01', 'D1_AN2_CALIB02', 'D1_AN2_CALIB03', 'D1_AN2_CALIB04',
			'D1_AN2_CALIB05', 'D1_AN2_CALIB06', 'D1_AN2_CALIB07', 'D1_AN2_CALIB08', 'D1_AN2_CALIB09',
			'D1_AN2_CALIB10', 'D1_AN2_CALIB11'];
	}
	minNum() {
		let j1939 = new Data('D1_J1939_ENGINE_MODEL').valNum();
		if (!j1939) {
			let calibValArray = [];
			this.tagsArray.forEach((item) => {
				calibValArray.push(new Data(item).valNum());
			});
			return Math.min(...calibValArray);
		}
		return 0;
	}
	maxNum() {
		const MAX_CELCIUS = 150;
		let unit = new Data('D1_WATER_TEMP').unit();
		let j1939 = new Data('D1_J1939_ENGINE_MODEL').valNum();
		if (!j1939) {
			let calibValArray = [];
			this.tagsArray.forEach((item) => {
				calibValArray.push(new Data(item).valNum());
			});
			return Math.max(...calibValArray);
		} else if (unit === 'R2_FARENHEIT') {
			return (MAX_CELCIUS * 1.8) + 32;
		}
		return MAX_CELCIUS;
	}
}

class D1_VOLT_BATT extends Data {
	constructor(tag) {
		super(tag);
	}

	maxNum() {
		return 36;
	}
}

class D1_AN_MEASURE1 extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_AN1_CALIB01', 'D1_AN1_CALIB02', 'D1_AN1_CALIB03', 'D1_AN1_CALIB04',
			'D1_AN1_CALIB05', 'D1_AN1_CALIB06', 'D1_AN1_CALIB07', 'D1_AN1_CALIB08', 'D1_AN1_CALIB09',
			'D1_AN1_CALIB10', 'D1_AN1_CALIB11']);
		this.tagsArray = ['D1_AN1_CALIB01', 'D1_AN1_CALIB02', 'D1_AN1_CALIB03', 'D1_AN1_CALIB04',
			'D1_AN1_CALIB05', 'D1_AN1_CALIB06', 'D1_AN1_CALIB07', 'D1_AN1_CALIB08', 'D1_AN1_CALIB09',
			'D1_AN1_CALIB10', 'D1_AN1_CALIB11'];
	}

	minNum() {
		let calibValArray = [];
		this.tagsArray.forEach((item) => {
			calibValArray.push(new Data(item).valNum());
		});
		return Math.min(...calibValArray);
	}

	maxNum() {
		let calibValArray = [];
		this.tagsArray.forEach((item) => {
			calibValArray.push(new Data(item).valNum());
		});
		return Math.max(...calibValArray);
	}
}

class D1_AN_MEASURE2 extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_AN2_CALIB01', 'D1_AN2_CALIB02', 'D1_AN2_CALIB03', 'D1_AN2_CALIB04',
			'D1_AN2_CALIB05', 'D1_AN2_CALIB06', 'D1_AN2_CALIB07', 'D1_AN2_CALIB08', 'D1_AN2_CALIB09',
			'D1_AN2_CALIB10', 'D1_AN2_CALIB11']);
		this.tagsArray = ['D1_AN2_CALIB01', 'D1_AN2_CALIB02', 'D1_AN2_CALIB03', 'D1_AN2_CALIB04',
			'D1_AN2_CALIB05', 'D1_AN2_CALIB06', 'D1_AN2_CALIB07', 'D1_AN2_CALIB08', 'D1_AN2_CALIB09',
			'D1_AN2_CALIB10', 'D1_AN2_CALIB11'];
	}
	minNum() {
		let calibValArray = [];
		this.tagsArray.forEach((item) => {
			calibValArray.push(new Data(item).valNum());
		});
		return Math.min(...calibValArray);
	}

	maxNum() {
		let calibValArray = [];
		this.tagsArray.forEach((item) => {
			calibValArray.push(new Data(item).valNum());
		});
		return Math.max(...calibValArray);
	}
}

class D1_AN_MEASURE3 extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_AN3_CALIB01', 'D1_AN3_CALIB02', 'D1_AN3_CALIB03', 'D1_AN3_CALIB04',
			'D1_AN3_CALIB05', 'D1_AN3_CALIB06', 'D1_AN3_CALIB07', 'D1_AN3_CALIB08', 'D1_AN3_CALIB09',
			'D1_AN3_CALIB10', 'D1_AN3_CALIB11']);
		this.tagsArray = ['D1_AN3_CALIB01', 'D1_AN3_CALIB02', 'D1_AN3_CALIB03', 'D1_AN3_CALIB04',
			'D1_AN3_CALIB05', 'D1_AN3_CALIB06', 'D1_AN3_CALIB07', 'D1_AN3_CALIB08', 'D1_AN3_CALIB09',
			'D1_AN3_CALIB10', 'D1_AN3_CALIB11'];
	}
	minNum() {
		let calibValArray = [];
		this.tagsArray.forEach((item) => {
			calibValArray.push(new Data(item).valNum());
		});
		return Math.min(...calibValArray);
	}

	maxNum() {
		let calibValArray = [];
		this.tagsArray.forEach((item) => {
			calibValArray.push(new Data(item).valNum());
		});
		return Math.max(...calibValArray);
	}
}

class D1_J1939_MTU_ERROR_CODE extends Data {
	constructor(tag) {
		super(tag);
	}

	isEnabled() {
		let engineConfig = new Data('D1_J1939_ENGINE_MODEL').valNum();
		if (engineConfig === 10) {
			return true;
		}
		return false;
	}
}

//Maintenance meter

class D1_METER_1_HOUR extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_HOUR_CYCLE1']);
	}
}

class D1_METER_2_HOUR extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_HOUR_CYCLE2']);
	}
}

class D1_METER_3_HOUR extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_HOUR_CYCLE3']);
	}
}

class D1_METER_4_HOUR extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_HOUR_CYCLE4']);
	}
}

class D1_METER_5_HOUR extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_HOUR_CYCLE5']);
	}
}

class D1_METER_1_DAY extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_DAY_CYCLE1']);
	}
}

class D1_METER_2_DAY extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_DAY_CYCLE2']);
	}
}

class D1_METER_3_DAY extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_DAY_CYCLE3']);
	}
}

class D1_METER_4_DAY extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_DAY_CYCLE4']);
	}
}

class D1_METER_5_DAY extends Data {
	constructor(tag) {
		super(tag);
		this.setDependencies(['D1_DAY_CYCLE5']);
	}
}

//Synchro

class D1_VOLT_BUS_GEN extends Data {
	constructor(tag) {
		super(tag);
	}
	minNum() {
		return -20;
	}
	maxNum() {
		return 20;
	}
}

class D1_FREQ_BUS_GEN extends Data {
	constructor(tag) {
		super(tag);
	}
	minNum() {
		return -3;
	}
	maxNum() {
		return 3;
	}
}

//CanOPEN DI/DO
overrideData.D1_CANOPEN_CONFIG_TYPE = D1_CANOPEN_CONFIG_TYPE;
overrideData.D1_CANOPEN_DI1 = D1_CANOPEN_DI1;
overrideData.D1_CANOPEN_DI2 = D1_CANOPEN_DI2;
overrideData.D1_CANOPEN_DI3 = D1_CANOPEN_DI3;
overrideData.D1_CANOPEN_DI4 = D1_CANOPEN_DI4;
overrideData.D1_CANOPEN_DI5 = D1_CANOPEN_DI5;
overrideData.D1_CANOPEN_DI6 = D1_CANOPEN_DI6;
overrideData.D1_CANOPEN_DI7 = D1_CANOPEN_DI7;
overrideData.D1_CANOPEN_DI8 = D1_CANOPEN_DI8;
overrideData.D1_CANOPEN_DI9 = D1_CANOPEN_DI9;
overrideData.D1_CANOPEN_DI10 = D1_CANOPEN_DI10;
overrideData.D1_CANOPEN_DI11 = D1_CANOPEN_DI11;
overrideData.D1_CANOPEN_DI12 = D1_CANOPEN_DI12;
overrideData.D1_CANOPEN_DI13 = D1_CANOPEN_DI13;
overrideData.D1_CANOPEN_DI14 = D1_CANOPEN_DI14;
overrideData.D1_CANOPEN_DI15 = D1_CANOPEN_DI15;
overrideData.D1_CANOPEN_DI16 = D1_CANOPEN_DI16;
overrideData.D1_CANOPEN_DI17 = D1_CANOPEN_DI17;
overrideData.D1_CANOPEN_DI18 = D1_CANOPEN_DI18;
overrideData.D1_CANOPEN_DI19 = D1_CANOPEN_DI19;
overrideData.D1_CANOPEN_DI20 = D1_CANOPEN_DI20;
overrideData.D1_CANOPEN_DI21 = D1_CANOPEN_DI21;
overrideData.D1_CANOPEN_DI22 = D1_CANOPEN_DI22;
overrideData.D1_CANOPEN_DI23 = D1_CANOPEN_DI23;
overrideData.D1_CANOPEN_DI24 = D1_CANOPEN_DI24;
overrideData.D1_CANOPEN_DI25 = D1_CANOPEN_DI25;
overrideData.D1_CANOPEN_DI26 = D1_CANOPEN_DI26;
overrideData.D1_CANOPEN_DI27 = D1_CANOPEN_DI27;
overrideData.D1_CANOPEN_DI28 = D1_CANOPEN_DI28;
overrideData.D1_CANOPEN_DI29 = D1_CANOPEN_DI29;
overrideData.D1_CANOPEN_DI30 = D1_CANOPEN_DI30;
overrideData.D1_CANOPEN_DI31 = D1_CANOPEN_DI31;
overrideData.D1_CANOPEN_DI32 = D1_CANOPEN_DI32;

overrideData.D1_DO01 = D1_DO01;
overrideData.D1_DO02 = D1_DO02;
overrideData.D1_DO03 = D1_DO03;
overrideData.D1_DO04 = D1_DO04;
overrideData.D1_DO05 = D1_DO05;
overrideData.D1_DO06 = D1_DO06;
overrideData.D1_DO07 = D1_DO07;
overrideData.D1_DO08 = D1_DO08;
overrideData.D1_DO09 = D1_DO09;
overrideData.D1_DO10 = D1_DO10;
overrideData.D1_DO11 = D1_DO11;
overrideData.D1_DO12 = D1_DO12;
overrideData.D1_DO13 = D1_DO13;
overrideData.D1_DO14 = D1_DO14;
overrideData.D1_DO15 = D1_DO15;
overrideData.D1_DO16 = D1_DO16;
overrideData.D1_DO17 = D1_DO17;
overrideData.D1_DO18 = D1_DO18;
overrideData.D1_DO19 = D1_DO19;
overrideData.D1_DO20 = D1_DO20;
overrideData.D1_DO21 = D1_DO21;
overrideData.D1_DO22 = D1_DO22;
overrideData.D1_DO23 = D1_DO23;
overrideData.D1_DO24 = D1_DO24;
overrideData.D1_DO25 = D1_DO25;
overrideData.D1_DO26 = D1_DO26;
overrideData.D1_DO27 = D1_DO27;
overrideData.D1_DO28 = D1_DO28;
overrideData.D1_DO29 = D1_DO29;
overrideData.D1_DO30 = D1_DO30;
overrideData.D1_DO31 = D1_DO31;
overrideData.D1_DO32 = D1_DO32;
//I/O
overrideData.D1_INPUT1 = D1_INPUT1;
//generator
overrideData.D1_GEN_V1 = D1_GEN_V1;
overrideData.D1_GEN_V2 = D1_GEN_V2;
overrideData.D1_GEN_V3 = D1_GEN_V3;
overrideData.D1_GEN_U31 = D1_GEN_U31;
overrideData.D1_GEN_U23 = D1_GEN_U23;
overrideData.D1_GEN_U12 = D1_GEN_U12;
overrideData.D1_GEN_I1 = D1_GEN_I1;
overrideData.D1_GEN_I2 = D1_GEN_I2;
overrideData.D1_GEN_I3 = D1_GEN_I3;
overrideData.D1_GEN_P1 = D1_GEN_P1;
overrideData.D1_GEN_P2 = D1_GEN_P2;
overrideData.D1_GEN_P3 = D1_GEN_P3;
overrideData.D1_GEN_Q1 = D1_GEN_Q1;
overrideData.D1_GEN_Q2 = D1_GEN_Q2;
overrideData.D1_GEN_Q3 = D1_GEN_Q3;
overrideData.D1_GEN_COSPHI1 = D1_GEN_COSPHI1;
overrideData.D1_GEN_COSPHI2 = D1_GEN_COSPHI2;
overrideData.D1_GEN_COSPHI3 = D1_GEN_COSPHI3;
overrideData.D1_GEN_KW = D1_GEN_KW;
overrideData.D1_GEN_KVAR = D1_GEN_KVAR;

//bus
overrideData.D1_BUS_V1 = D1_BUS_V1;
overrideData.D1_BUS_V2 = D1_BUS_V2;
overrideData.D1_BUS_V3 = D1_BUS_V3;
overrideData.D1_BUS_U31 = D1_BUS_U31;
overrideData.D1_BUS_U23 = D1_BUS_U23;
overrideData.D1_BUS_U12 = D1_BUS_U12;
overrideData.D1_BUS_I1 = D1_BUS_I1;
overrideData.D1_BUS_KW = D1_BUS_P;
overrideData.D1_BUS_KVAR = D1_BUS_Q;

//engine
overrideData.D1_ENGINE_RPM = D1_ENGINE_RPM;
overrideData.D1_OIL_PRESS = D1_OIL_PRESS;
overrideData.D1_WATER_TEMP = D1_WATER_TEMP;
overrideData.D1_VOLT_BATT = D1_VOLT_BATT;
overrideData.D1_AN_MEASURE1 = D1_AN_MEASURE1;
overrideData.D1_AN_MEASURE2 = D1_AN_MEASURE2;
overrideData.D1_AN_MEASURE3 = D1_AN_MEASURE3;
overrideData.D1_J1939_MTU_ERROR_CODE = D1_J1939_MTU_ERROR_CODE;

//maintenance
overrideData.D1_METER_1_HOUR = D1_METER_1_HOUR;
overrideData.D1_METER_2_HOUR = D1_METER_2_HOUR;
overrideData.D1_METER_3_HOUR = D1_METER_3_HOUR;
overrideData.D1_METER_4_HOUR = D1_METER_4_HOUR;
overrideData.D1_METER_5_HOUR = D1_METER_5_HOUR;
overrideData.D1_METER_1_DAY = D1_METER_1_DAY;
overrideData.D1_METER_2_DAY = D1_METER_2_DAY;
overrideData.D1_METER_3_DAY = D1_METER_3_DAY;
overrideData.D1_METER_4_DAY = D1_METER_4_DAY;
overrideData.D1_METER_5_DAY = D1_METER_5_DAY;

//Synchro
overrideData.D1_VOLT_BUS_GEN = D1_VOLT_BUS_GEN;
overrideData.D1_FREQ_BUS_GEN = D1_FREQ_BUS_GEN;

export default overrideData;
