'use strict'

let Stampit = require('stampit')
let Promise = require('bluebird')

module.exports = Stampit()
  .init(function () {
    let init = function () {
      this.addResponseHandler(20, onResponse)
    }.bind(this)

    let onResponse = function (pdu, request) {
      this.log.debug('handling read file record response.')
      this.log.debug('on read file record got PDU: ' + JSON.stringify(pdu) + ' pdu.length:' + pdu.length)
      this.log.debug('request: ' + JSON.stringify(request))

      if (pdu.length < 2) {
        request.defer.reject()
        return
      }

      try {
        let fc = pdu.readUInt8(0)
        if (fc !== 20) {
          request.defer.reject()
          return
        }

        let byteCount = pdu.readUInt8(1)
        let resp = {
          fc: fc,
          byteCount: byteCount,
          payload: pdu.slice(2),
          register: []
        }

        let registerCount = Math.floor(byteCount / 2)

        for (let i = 0; i < registerCount; i += 1) {
          resp.register.push(pdu.readUInt16BE(2 + (i * 2)))
        }

        request.defer.resolve(resp)
      } catch(e) {
        console.log('readFileRecord error', e)
        console.log('pdu', pdu)
        request.defer.reject()
      }
    }.bind(this)

    this.readFileRecord = function (fileNumber, recordNumber, recordLength) {
      return new Promise(function (resolve, reject) {
        let fc = 20
        let byteCount = 7 /* Pour la lecture d'un enregistrement */
        let refType = 6
        let pdu = Buffer.allocUnsafe(9)

        pdu.writeUInt8(fc)
        pdu.writeUInt8(byteCount, 1)
        pdu.writeUInt8(refType, 2)
        pdu.writeUInt16BE(fileNumber, 3)
        pdu.writeUInt16BE(recordNumber, 5)
        pdu.writeUInt16BE(recordLength, 7)

        this.queueRequest(fc, pdu, { resolve: resolve, reject: reject })
      }.bind(this))
    }

    init()
  })
